==> binnie-mods-1.12-2.2.0.3-sources.jar: binnie/extratrees/item/ItemHops.java <==
package binnie.extratrees.item;

import net.minecraft.block.Block;
import net.minecraft.block.SoundType;
import net.minecraft.block.state.IBlockState;
import net.minecraft.client.renderer.block.model.ModelResourceLocation;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.EnumActionResult;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.EnumHand;
import net.minecraft.util.SoundCategory;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.IBlockAccess;
import net.minecraft.world.World;

import net.minecraftforge.client.model.ModelLoader;
import net.minecraftforge.common.EnumPlantType;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import forestry.api.core.IItemModelRegister;
import forestry.api.core.IModelManager;
import forestry.api.core.Tabs;

import binnie.core.util.I18N;

public class ItemHops extends Item implements net.minecraftforge.common.IPlantable, IItemModelRegister {
	private final Block crops;
	private final Block soil;
	
	public ItemHops(Block crops, Block soil) {
		this.crops = crops;
		this.soil = soil;
		func_77655_b("hops");
		setRegistryName("hops");
		this.func_77637_a(Tabs.tabArboriculture);
	}
	
	@SideOnly(Side.CLIENT)
	@Override
	public void registerModel(Item item, IModelManager manager) {
		ModelLoader.setCustomModelResourceLocation(item, 0, new ModelResourceLocation(getRegistryName(), "inventory"));
	}
	
	public EnumActionResult func_180614_a(EntityPlayer player, World worldIn, BlockPos pos, EnumHand hand, EnumFacing facing, float hitX, float hitY, float hitZ) {
		IBlockState state = worldIn.func_180495_p(pos);
		Block block = state.func_177230_c();
		
		ItemStack itemstack = player.func_184586_b(hand);
		
		if (!itemstack.func_190926_b() && facing == EnumFacing.UP && player.func_175151_a(pos, facing, itemstack) && state.func_177230_c().canSustainPlant(state, worldIn, pos, EnumFacing.UP, this) && worldIn.func_175623_d(pos.func_177984_a())) {
			pos = pos.func_177984_a();
			IBlockState blockState = crops.getStateForPlacement(worldIn, pos, facing, hitX, hitY, hitZ, 0, player, hand);
			
			if (!worldIn.func_180501_a(pos, blockState, 11)) {
				return EnumActionResult.FAIL;
			} else {
				blockState = worldIn.func_180495_p(pos);
				
				if (blockState.func_177230_c() == crops) {
					blockState.func_177230_c().func_180633_a(worldIn, pos, blockState, player, itemstack);
				}
				
				SoundType soundtype = blockState.func_177230_c().getSoundType(blockState, worldIn, pos, player);
				worldIn.func_184133_a(player, pos, soundtype.func_185841_e(), SoundCategory.BLOCKS, (soundtype.func_185843_a() + 1.0F) / 2.0F, soundtype.func_185847_b() * 0.8F);
				itemstack.func_190918_g(1);
				return EnumActionResult.SUCCESS;
			}
		} else {
			return EnumActionResult.FAIL;
		}
	}
	
	@Override
	public String func_77653_i(ItemStack itemStack) {
		return I18N.localise("extratrees.item.hops.name");
	}
	
	@Override
	public EnumPlantType getPlantType(IBlockAccess world, BlockPos pos) {
		return EnumPlantType.Crop;
	}
	
	@Override
	public IBlockState getPlant(IBlockAccess world, BlockPos pos) {
		return crops.func_176223_P();
	}
}

==> binnie-mods-1.12-2.3.0.8-sources.jar: binnie/extratrees/item/ItemHops.java <==
package binnie.extratrees.item;

import net.minecraft.block.Block;
import net.minecraft.block.SoundType;
import net.minecraft.block.state.IBlockState;
import net.minecraft.client.renderer.block.model.ModelResourceLocation;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.util.EnumActionResult;
import net.minecraft.util.EnumFacing;
import net.minecraft.util.EnumHand;
import net.minecraft.util.SoundCategory;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.IBlockAccess;
import net.minecraft.world.World;

import net.minecraftforge.client.model.ModelLoader;
import net.minecraftforge.common.EnumPlantType;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import forestry.api.core.IItemModelRegister;
import forestry.api.core.IModelManager;
import forestry.api.core.Tabs;

import binnie.core.util.I18N;

public class ItemHops extends Item implements net.minecraftforge.common.IPlantable, IItemModelRegister {
	private final Block crops;
	private final Block soil;
	
	public ItemHops(Block crops, Block soil) {
		this.crops = crops;
		this.soil = soil;
		setUnlocalizedName("hops");
		setRegistryName("hops");
		this.setCreativeTab(Tabs.tabArboriculture);
	}
	
	@SideOnly(Side.CLIENT)
	@Override
	public void registerModel(Item item, IModelManager manager) {
		ModelLoader.setCustomModelResourceLocation(item, 0, new ModelResourceLocation(getRegistryName(), "inventory"));
	}
	
	public EnumActionResult onItemUse(EntityPlayer player, World worldIn, BlockPos pos, EnumHand hand, EnumFacing facing, float hitX, float hitY, float hitZ) {
		IBlockState state = worldIn.getBlockState(pos);
		Block block = state.getBlock();
		
		ItemStack itemstack = player.getHeldItem(hand);
		
		if (!itemstack.isEmpty() && facing == EnumFacing.UP && player.canPlayerEdit(pos, facing, itemstack) && state.getBlock().canSustainPlant(state, worldIn, pos, EnumFacing.UP, this) && worldIn.isAirBlock(pos.up())) {
			pos = pos.up();
			IBlockState blockState = crops.getStateForPlacement(worldIn, pos, facing, hitX, hitY, hitZ, 0, player, hand);
			
			if (!worldIn.setBlockState(pos, blockState, 11)) {
				return EnumActionResult.FAIL;
			} else {
				blockState = worldIn.getBlockState(pos);
				
				if (blockState.getBlock() == crops) {
					blockState.getBlock().onBlockPlacedBy(worldIn, pos, blockState, player, itemstack);
				}
				
				SoundType soundtype = blockState.getBlock().getSoundType(blockState, worldIn, pos, player);
				worldIn.playSound(player, pos, soundtype.getPlaceSound(), SoundCategory.BLOCKS, (soundtype.getVolume() + 1.0F) / 2.0F, soundtype.getPitch() * 0.8F);
				itemstack.shrink(1);
				return EnumActionResult.SUCCESS;
			}
		} else {
			return EnumActionResult.FAIL;
		}
	}
	
	@Override
	public String getItemStackDisplayName(ItemStack itemStack) {
		return I18N.localise("extratrees.item.hops.name");
	}
	
	@Override
	public EnumPlantType getPlantType(IBlockAccess world, BlockPos pos) {
		return EnumPlantType.Crop;
	}
	
	@Override
	public IBlockState getPlant(IBlockAccess world, BlockPos pos) {
		return crops.getDefaultState();
	}
}
